# EDA and Beyond - Python library for automating common procedures in machine learning 


**Contributors**: [Freda Xin](www.linkedin.com/in/freda-xin), [Mahdi Shadkam-Farrokhi](https://github.com/Shaddyjr)


---
## Project Description 
The package provides a collection of automation tools for some common procedures
in machine learning. The current version aims to streamline the EDA and modeling
process for [Scikit-Learn models](https://scikit-learn.org/stable/). 


The package consists of two modules: 
* [eda_tools](https://github.com/FredaXin/eda_and_beyond/blob/master/eda_and_beyond/eda_tools.py):
  provides functions to automate common procedures in EDA, model
    preparation, and data visualization etc. 

* [modeling_tools](https://github.com/FredaXin/eda_and_beyond/blob/master/eda_and_beyond/modeling_tools.py):
  provides a class object that includes methods to streamline the modeling process for Scikit-Learn models. 
 
This is an open-source project. Contributors are welcome. :) 
 

--- 
## Installation 

```
pip install eda_and_beyond
```

---
## More Resources

**[Blog post on using Python functions in EDA](https://towardsdatascience.com/creating-python-functions-for-exploratory-data-analysis-and-data-cleaning-2c462961bd71?sk=ea9ba027ee85504c078145f442b204b9)**  
**[Blog post on using Python classes in modeling]() (coming soon)**   
